@@ -76,6 +76,35 @@ pub(crate) fn extract_symbol(_market_type: MarketType, msg: &str) -> Result<Stri
     }
 }
 
+pub(crate) fn extract_timestamp(
+    _market_type: MarketType,
+    msg: &str,
+) -> Result<Option<i64>, SimpleError> {
+    let ws_msg = serde_json::from_str::<WebsocketMsg<Value>>(msg).map_err(|_e| {
+        SimpleError::new(format!(
+            "Failed to deserialize {} to WebsocketMsg<Value>",
+            msg
+        ))
+    })?;
+    let data = ws_msg.params.data;
+    if data.is_object() {
+        Ok(Some(data["timestamp"].as_i64().unwrap()))
+    } else if data.is_array() {
+        let arr = data.as_array().unwrap();
+        let timestamp = arr.iter().fold(std::i64::MIN, |a, x| {
+            a.max(x["timestamp"].as_i64().unwrap())
+        });
+
+        if timestamp == std::i64::MIN {
+            Err(SimpleError::new(format!("data is empty in {}", msg)))
+        } else {
+            Ok(Some(timestamp))
+        }
+    } else {
+        Err(SimpleError::new(format!("Unknown message format: {}", msg)))
+    }
+}
+
 pub(crate) fn get_msg_type(msg: &str) -> MessageType {
     if let Ok(ws_msg) = serde_json::from_str::<WebsocketMsg<Value>>(msg) {
         let channel = {
